@@ -9,20 +9,30 @@ not a Python `module`.
 */
 
 use {
-    super::python_resources::PythonResourcesState,
-    lazy_static::lazy_static,
+    crate::python_resources::PythonResourcesState,
     memory_module_sys::{
         MemoryFreeLibrary, MemoryGetProcAddress, MemoryLoadLibraryEx, HCUSTOMMODULE,
     },
-    std::collections::HashMap,
-    std::ffi::{c_void, CStr},
-    std::sync::atomic::{AtomicUsize, Ordering},
-    std::sync::Mutex,
-    winapi::shared::basetsd::SIZE_T,
-    winapi::shared::minwindef::{BOOL, DWORD, FARPROC, HINSTANCE__, LPVOID},
-    winapi::shared::ntdef::LPCSTR,
-    winapi::um::libloaderapi::{FreeLibrary, GetProcAddress, LoadLibraryA},
-    winapi::um::memoryapi::{VirtualAlloc, VirtualFree},
+    once_cell::sync::Lazy,
+    std::{
+        collections::HashMap,
+        ffi::{c_void, CStr},
+        sync::{
+            atomic::{AtomicUsize, Ordering},
+            Mutex,
+        },
+    },
+    winapi::{
+        shared::{
+            basetsd::SIZE_T,
+            minwindef::{BOOL, DWORD, FARPROC, HINSTANCE__, LPVOID},
+            ntdef::LPCSTR,
+        },
+        um::{
+            libloaderapi::{FreeLibrary, GetProcAddress, LoadLibraryA},
+            memoryapi::{VirtualAlloc, VirtualFree},
+        },
+    },
 };
 
 /// Holds state for a module loaded from memory.
@@ -57,14 +67,12 @@ struct MemoryModules {
 
 unsafe impl Send for MemoryModules {}
 
-lazy_static! {
-    static ref MEMORY_MODULES: Mutex<MemoryModules> = {
-        Mutex::new(MemoryModules {
-            modules: HashMap::new(),
-            module_ptrs: Vec::new(),
-        })
-    };
-}
+static MEMORY_MODULES: Lazy<Mutex<MemoryModules>> = Lazy::new(|| {
+    Mutex::new(MemoryModules {
+        modules: HashMap::new(),
+        module_ptrs: Vec::new(),
+    })
+});
 
 /// Load a library from memory, possibly retrieving missing libraries from resources state.
 ///
