@@ -3,14 +3,23 @@
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 use {
-    crate::importer::ImporterState,
+    crate::{
+        importer::ImporterState,
+        pkg_resources::create_oxidized_pkg_resources_provider,
+        python_resources::{name_at_package_hierarchy, name_within_package_hierarchy},
+    },
     cpython::{
         exc::{IOError, NotImplementedError, ValueError},
-        py_class, NoArgs, ObjectProtocol, PyBytes, PyClone, PyDict, PyErr, PyList, PyModule,
-        PyObject, PyResult, PyString, PyType, Python, PythonObject, ToPyObject,
+        py_class, NoArgs, ObjectProtocol, PyBytes, PyClone, PyDict, PyErr, PyList, PyObject,
+        PyResult, PyString, PyType, Python, PythonObject, ToPyObject,
     },
     python_packed_resources::data::Resource,
-    std::{borrow::Cow, collections::HashMap, path::Path, sync::Arc},
+    std::{
+        borrow::Cow,
+        collections::{BTreeMap, BTreeSet, HashMap},
+        path::Path,
+        sync::Arc,
+    },
 };
 
 // Emulates importlib.metadata.Distribution._discover_resolvers().
@@ -32,7 +41,7 @@ fn discover_resolvers(py: Python) -> PyResult<PyList> {
 }
 
 // A importlib.metadata.Distribution allowing access to package distribution data.
-py_class!(class OxidizedDistribution |py| {
+py_class!(pub(crate) class OxidizedDistribution |py| {
     data state: Arc<ImporterState>;
     data package: String;
 
@@ -42,7 +51,7 @@ py_class!(class OxidizedDistribution |py| {
     }
 
     @classmethod
-    def discover(cls, *args, **kwargs) -> PyResult<PyObject> {
+    def discover(cls, *_args, **kwargs) -> PyResult<PyObject> {
         OxidizedDistribution::discover_impl(py, cls, kwargs)
     }
 
@@ -327,7 +336,76 @@ pub(crate) fn find_distributions(
         .into_object())
 }
 
-fn resolve_package_distribution_resource<'a>(
+/// pkg_resources distribution finder for sys.path entries.
+///
+/// `state` meta path importer state.
+/// `search_path` is the `sys.path` item being evaluated.
+/// `only` if True only yield items that would be importable if `search_path` were
+/// on `sys.path`. Otherwise yields items that are in or under `search_path`.
+/// `package_target` is the package target from the `OxidizedPathEntryFinder`.
+pub(crate) fn find_pkg_resources_distributions(
+    py: Python,
+    state: Arc<ImporterState>,
+    search_path: &str,
+    only: bool,
+    package_target: Option<&str>,
+) -> PyResult<PyList> {
+    let resources = &state.get_resources_state().resources;
+
+    let pkg_resources = py.import("pkg_resources")?;
+    let distribution_type = pkg_resources.get(py, "Distribution")?;
+
+    let distributions = resources
+        .values()
+        // Find packages with distribution resources.
+        .filter(|r| {
+            r.is_package
+                && (r.in_memory_distribution_resources.is_some()
+                    || r.relative_path_distribution_resources.is_some())
+        })
+        .filter(|r| {
+            if only {
+                name_at_package_hierarchy(&r.name, package_target)
+            } else {
+                name_within_package_hierarchy(&r.name, package_target)
+            }
+        })
+        .map(|r| {
+            let oxidized_distribution =
+                OxidizedDistribution::create_instance(py, state.clone(), r.name.to_string())?;
+
+            let metadata = oxidized_distribution.metadata(py)?;
+
+            let project_name = metadata.get_item(py, "Name")?;
+            let version = metadata.get_item(py, "Version")?;
+
+            let location = format!("{}/{}", search_path, r.name.replace('.', "/"));
+
+            let provider =
+                create_oxidized_pkg_resources_provider(py, state.clone(), r.name.to_string())?;
+
+            let kwargs = PyDict::new(py);
+            kwargs.set_item(py, "location", PyString::new(py, &location))?;
+            kwargs.set_item(py, "metadata", provider.into_object())?;
+            kwargs.set_item(py, "project_name", project_name)?;
+            kwargs.set_item(py, "version", version)?;
+
+            Ok((&r.name, distribution_type.call(py, NoArgs, Some(&kwargs))?))
+        })
+        // Collect into a BTreeMap to deduplicate and facilitate deterministic output.
+        .filter_map(|kv: PyResult<(_, PyObject)>| kv.ok())
+        .collect::<BTreeMap<_, PyObject>>();
+
+    Ok(PyList::new(
+        py,
+        &distributions
+            .into_iter()
+            .map(|(_, v)| v)
+            .collect::<Vec<_>>(),
+    ))
+}
+
+pub(crate) fn resolve_package_distribution_resource<'a>(
     resources: &'a HashMap<Cow<'a, str>, Resource<'a, u8>>,
     origin: &Path,
     package: &str,
@@ -355,12 +433,90 @@ fn resolve_package_distribution_resource<'a>(
     }
 }
 
-pub(crate) fn module_init(py: Python, m: &PyModule) -> PyResult<()> {
-    m.add(
-        py,
-        "OxidizedDistribution",
-        py.get_type::<crate::package_metadata::OxidizedDistribution>(),
-    )?;
+/// Whether a metadata resource name is a directory.
+pub(crate) fn metadata_name_is_directory<'a>(
+    resources: &'a HashMap<Cow<'a, str>, Resource<'a, u8>>,
+    package: &str,
+    name: &str,
+) -> bool {
+    let name = name.replace('\\', "/");
 
-    Ok(())
+    let prefix = if name.ends_with('/') {
+        name
+    } else {
+        format!("{}/", name)
+    };
+
+    if let Some(entry) = resources.get(package) {
+        if let Some(resources) = &entry.in_memory_distribution_resources {
+            if resources.keys().any(|path| path.starts_with(&prefix)) {
+                return true;
+            }
+        }
+
+        if let Some(resources) = &entry.relative_path_distribution_resources {
+            if resources.keys().any(|path| path.starts_with(&prefix)) {
+                return true;
+            }
+        }
+
+        false
+    } else {
+        false
+    }
+}
+
+/// List contents of a metadata directory.
+pub(crate) fn metadata_list_directory<'a>(
+    resources: &'a HashMap<Cow<'a, str>, Resource<'a, u8>>,
+    package: &str,
+    name: &str,
+) -> Vec<&'a str> {
+    let name = name.replace('\\', "/");
+
+    let prefix = if name.ends_with('/') {
+        Some(name)
+    } else if name.is_empty() {
+        None
+    } else {
+        Some(format!("{}/", name))
+    };
+
+    let filter_map_resource = |path: &'a Cow<'a, str>| -> Option<&'a str> {
+        match &prefix {
+            Some(prefix) => {
+                if let Some(name) = path.strip_prefix(prefix) {
+                    if name.contains('/') {
+                        None
+                    } else {
+                        Some(name)
+                    }
+                } else {
+                    None
+                }
+            }
+            None => {
+                // Empty string input matches root directory.
+                if path.contains('/') {
+                    None
+                } else {
+                    Some(path)
+                }
+            }
+        }
+    };
+
+    let mut entries = BTreeSet::new();
+
+    if let Some(entry) = resources.get(package) {
+        if let Some(resources) = &entry.in_memory_distribution_resources {
+            entries.extend(resources.keys().filter_map(filter_map_resource));
+        }
+
+        if let Some(resources) = &entry.relative_path_distribution_resources {
+            entries.extend(resources.keys().filter_map(filter_map_resource));
+        }
+    }
+
+    entries.into_iter().collect::<Vec<_>>()
 }
