@@ -49,4 +49,4 @@ class TestImporterBuiltins(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    unittest.main(exit=False)
+    unittest.main()
